@@ -915,10 +915,12 @@ OBJECT *o_complex_copy_embedded(TOPLEVEL *toplevel, OBJECT *list_tail,
   temp_list = o_list_copy_all(toplevel,
                               o_current->complex->prim_objs->next,
                               new_obj->complex->prim_objs, 
-                              NORMAL_FLAG);
+                              toplevel->ADDING_SEL);
 	
   new_obj->complex->prim_objs = return_head(temp_list);
 
+  o_complex_recalc(toplevel, new_obj);
+
   /* here you need to create a list of attributes which need to be 
    * connected to the new list, probably make an attribute list and
    * fill it with sid's of the attributes */
